nose-machineout2
==================

``nose-machineout2`` is a fork of nose_machineout_ which originally written by Max Ischenko.
It seems the original branch (github.com/nvie/nose_machineout) is gone, thus I decied to start maintenance while nose.vim_ won't work on PyPI version.

.. _nose_machineout: https://pypi.python.org/pypi/nose_machineout
.. _nose.vim: https://github.com/lambdalisue/nose.vim

I added the following features

- Doctest support
- Python3 support
- A python package name ``machineout`` is renamed to ``nose_machineout``
